netapp_ontap.models.ldap_status API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ldap_status`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class LdapStatusSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the LdapStatus object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `code: Size GET`

    This field is no longer supported. Use ipv4.code or ipv6.code instead.

    Example: 65537300

  `dn_message: List[str] GET`

    The dn_message field of the ldap_status.

  `ipv4: LdapIpStatus GET`

    The ipv4 field of the ldap_status.

  `ipv4_state: str GET`

    This field is no longer supported. Use ipv4.state instead.

    Valid choices:

    - up
    - down
  `ipv6: LdapIpStatus GET`

    The ipv6 field of the ldap_status.

  `ipv6_state: str GET`

    This field is no longer supported. Use ipv6.state instead.

    Valid choices:

    - up
    - down
  `message: str GET`

    This field is no longer supported. Use ipv4.message or ipv6.message instead.

  `state: str GET`

    The status of the LDAP service for the SVM. The LDAP service is up if either `ipv4_state` or `ipv6_state` is up. The LDAP service is down if both `ipv4_state` and `ipv6_state` are down.

    Valid choices:

    - up
    - down